{%- extends '!footer.html' -%} {%- block extrafooter -%}
  <div role="footer_string">
    <p>
      {%- if meta is defined and meta is not none and 'footer_string' in meta -%}
        {{ meta.get('footer_string') }}
      {%- endif -%}
    </p>

    {% if show_source and source_url_prefix %}
      <a href="{{ source_url_prefix }}{{ pagename }}{{ page_source_suffix }}">{{ _('View page source') }}</a>
    {% elif show_source and has_source and sourcename %}
      <a href="{{ pathto('_sources/' + sourcename, true)|e }}" rel="nofollow"> {{ _('View page source') }}</a>
    {% endif %}

  </div>
{%- endblock -%}
