/* text colors

 Note:
 - red    same as restricted / created
 - orange same as highlyconfidential / draft
 - blue   same as confidential / verified
 - green  same as unrestricted / released
*/

.green       {            color:rgb( 33, 215,  38); }
.yellow      {            color:rgb(251, 251,  40); }
.orange      {            color:rgb(253, 149,  38); }
.red         {            color:rgb(253,  13,  27); }
.blue        {            color:rgb( 40,  36, 251); }
.white       {            color:rgb(255, 255, 255); }
.black       {            color:rgb(  0,   0,   0); }
.grey        {            color:rgb(128, 128, 128); }

.greyitalic  {            color:rgb(128, 128, 128); font-style: italic; }
