/* border around labels in the header with round corners, used for data
   data classification and document status */

.header-label {
    font-weight: bold;
    border: solid 1px lightgray;
    border-radius: 3px;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    padding-left: 3px;
    padding-right: 3px;
    padding-top: 1px;
    padding-bottom: 1px;
    width: fit-content;
}

/* label colors used in the header */

.data-classification-restricted         { color:rgb(253,  13,  27); }
.data-classification-highlyconfidential { color:rgb(253, 149,  38); }
.data-classification-confidential       { color:rgb( 40,  36, 251); }
.data-classification-unrestricted       { color:rgb( 33, 215,  38); }

.document-status-created                { color:rgb(253,  13,  27); }
.document-status-draft                  { color:rgb(253, 149,  38); }
.document-status-verified               { color:rgb( 40,  36, 251); }
.document-status-released               { color:rgb( 33, 215,  38); }
