.green-cell  { background-color:rgb( 33, 215,  38); height:100%; display:grid; align-items:center; }
.yellow-cell { background-color:rgb(251, 251,  40); height:100%; display:grid; align-items:center; }
.orange-cell { background-color:rgb(253, 149,  38); height:100%; display:grid; align-items:center; }
.red-cell    { background-color:rgb(253,  13,  27); height:100%; display:grid; align-items:center; }
.blue-cell   { background-color:rgb( 40,  36, 251); height:100%; display:grid; align-items:center; }
.white-cell  { background-color:rgb(255, 255, 255); height:100%; display:grid; align-items:center; }
.black-cell  { background-color:rgb(  0,   0,   0); height:100%; display:grid; align-items:center; }
.grey-cell   { background-color:rgb(128, 128, 128); height:100%; display:grid; align-items:center; }

table.docutils.spaced { border-spacing: 3px; border-collapse: separate; }

table.docutils.centered    { text-align: center; }
table.docutils.centered th { text-align: center; }

table.docutils.colored            { vertical-align: middle; }
table.docutils.colored th         { padding: 0; margin: 0; vertical-align: middle;
                                    height: 0; height: -moz-available; }
table.docutils.colored td         { padding: 0; margin: 0; vertical-align: middle;
                                    height: 0; height: -moz-available; }
table.docutils.colored th > *     { padding: 8px 16px; }
table.docutils.colored td > *     { padding: 8px 16px; }
table.docutils.colored th > * > * { margin: 0; }
table.docutils.colored td > * > * { margin: 0; }

table.docutils.colored thead { height: 100%; }
table.docutils.colored tbody { height: 100%; }
